@@ -4,7 +4,6 @@ See LICENSE file.
 """
 
 import numpy as np
-from spec2nexus import spec
 import xrayutilities as xu
 
 # ==================================================================================
@@ -37,8 +36,5 @@ def gridScan(
     gridded_image_data = gridder.data
     coords = np.array([gridder.xaxis, gridder.yaxis, gridder.zaxis])
 
-    print(gridded_image_data.shape)
-    print(coords.shape)
-
     return gridded_image_data, coords
 
