@@ -5,6 +5,7 @@ See LICENSE file.
 
 # ==================================================================================
 
+import matplotlib.pyplot as plt
 import numpy as np
 import os
 from spec2nexus import spec
@@ -43,11 +44,18 @@ class Project:
         self.instrument_path = instrument_path
         self.detector_path = detector_path
 
+        # TODO: Validate SPEC file
         self.spec_data = spec.SpecDataFile(spec_path)
         self.scan_numbers = self.spec_data.getScanNumbers()
 
         # List of Scan objects
-        self.scans = [Scan(self.spec_data.getScan(i), project_path, spec_path, instrument_path, detector_path) for i in self.scan_numbers]
+        self.scans = []
+        for i in self.scan_numbers:
+            scan = Scan(self.spec_data.getScan(i), project_path, spec_path, instrument_path, detector_path)
+            if os.path.exists(scan.raw_image_path):
+                self.scans.append(scan)
+
+        self.scan_numbers = [scan.number for scan in self.scans]
 
 # ==================================================================================
 
@@ -76,18 +84,11 @@ class Scan:
         self.spec_path = spec_path
         self.instrument_path = instrument_path
         self.detector_path = detector_path
+        
         self.raw_image_path = f"{project_path}/images/{os.path.basename(os.path.splitext(self.spec_path)[0])}/S{str(self.number).zfill(3)}"
 
         # Data processing
         self.spec_data = spec_scan.data
-        self.raw_image_data = self.getImageData()
-        self.reciprocal_space_map = self.mapImageData()
-        self.h_map = self.reciprocal_space_map[:, :, :, 0]
-        self.k_map = self.reciprocal_space_map[:, :, :, 1]
-        self.l_map = self.reciprocal_space_map[:, :, :, 2]
-        self.h_grid_min, self.h_grid_max, self.h_grid_n = np.amin(self.h_map), np.amax(self.h_map), 250
-        self.k_grid_min, self.k_grid_max, self.k_grid_n = np.amin(self.k_map), np.amax(self.k_map), 250
-        self.l_grid_min, self.l_grid_max, self.l_grid_n = np.amin(self.l_map), np.amax(self.l_map), 250
         
     # ------------------------------------------------------------------------------
 
@@ -96,21 +97,32 @@ class Scan:
         Retrieves raw image data from path.
         """
 
+        # TODO: Check if path contents are valid
         image_paths = sorted(os.listdir(self.raw_image_path))
         image_data = []
 
         monitor_norm_factors = self.spec_scan.data["Ion_Ch_2"] * 200000
         filter_norm_factors = self.spec_scan.data["transm"] * 1
 
+        # TODO: Check if item is an image path with valid dims
         for i in range(len(image_paths)):
-            img_basepath = image_paths[i]
-            img_path = f"{self.raw_image_path}/{img_basepath}"
-            img_array = tiff.imread(img_path).T
-            img_array = img_array / (filter_norm_factors[i] * monitor_norm_factors[i])
-            image_data.append(img_array)
+            if image_paths[i].endswith("tif"):
+                img_basepath = image_paths[i]
+                img_path = f"{self.raw_image_path}/{img_basepath}"
+                try:
+                    img_array = tiff.imread(img_path).T
+                except:
+                    img_array = plt.imread(img_path).T
 
+                img_array = img_array / (filter_norm_factors[i] * monitor_norm_factors[i])
+                image_data.append(img_array)
+            else:
+                i =- 1
+
+        # TODO: Check if conversion is possible
         image_data = np.array(image_data)
         
+        # TODO: Validate returned dims
         return image_data
 
     # ------------------------------------------------------------------------------
@@ -120,9 +132,30 @@ class Scan:
         Creates a reciprocal space map from raw image data.
         """
 
-        rsm = mapScan(self.spec_scan, self.instrument_path, self.detector_path)
+        # TODO: Validate rsm dims
+        self.reciprocal_space_map = mapScan(self.spec_scan, self.instrument_path, self.detector_path)
 
-        return rsm
+        self.h_map = self.reciprocal_space_map[:, :, :, 0]
+        self.k_map = self.reciprocal_space_map[:, :, :, 1]
+        self.l_map = self.reciprocal_space_map[:, :, :, 2]
+        self.h_grid_min, self.h_grid_max, self.h_grid_n = np.amin(self.h_map), np.amax(self.h_map), 250
+        self.k_grid_min, self.k_grid_max, self.k_grid_n = np.amin(self.k_map), np.amax(self.k_map), 250
+        self.l_grid_min, self.l_grid_max, self.l_grid_n = np.amin(self.l_map), np.amax(self.l_map), 250
+
+    # ------------------------------------------------------------------------------
+
+    def setGriddingParameters(self, 
+        h_min, h_max, h_n,
+        k_min, k_max, k_n,
+        l_min, l_max, l_n
+    ):
+        """
+        Sets HKL bounds and point count for gridding interpolation.
+        """
+
+        self.h_grid_min, self.h_grid_max, self.h_grid_n = float(h_min), float(h_max), int(h_n)
+        self.k_grid_min, self.k_grid_max, self.k_grid_n = float(k_min), float(k_max), int(k_n)
+        self.l_grid_min, self.l_grid_max, self.l_grid_n = float(l_min), float(l_max), int(l_n)
 
     # ------------------------------------------------------------------------------
 
@@ -134,6 +167,7 @@ class Scan:
         hkl_max = (self.h_grid_max, self.k_grid_max, self.l_grid_max)
         hkl_n = (self.h_grid_n, self.k_grid_n, self.l_grid_n)
 
+        # TODO: Validate grid dims/coord lengths
         self.gridded_image_data, self.gridded_image_coords = gridScan(
             self.raw_image_data, 
             self.reciprocal_space_map,
